#
# spec file for package joker
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           joker
Version:        1.4.0
Release:        2.1
Summary:        Small Clojure interpreter, linter and formatter written in Go
License:        EPL-1.0
URL:            https://joker-lang.org
Source0:        https://github.com/candid82/joker/archive/refs/tags/v%{version}.tar.gz#/joker-%{version}.tar.gz
Source1:        vendor.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/candid82/joker/issues/491
Patch0:         reproducible.patch
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version} || 0%{?mageia}
BuildRequires:  go-rpm-macros
%else
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.18
%endif

%description
Joker is a small Clojure interpreter, linter and formatter written in Go.

%prep
%autosetup -p1
tar -zxf %{SOURCE1}

%build
GO111MODULE=on CGO_ENABLED=0 go generate ./...
GO111MODULE=on CGO_ENABLED=0 go build -mod=vendor -o %{name} -buildmode=pie \
	-ldflags "-s -w"

%install
install -D -m0755 %{name} %{buildroot}%{_bindir}/%{name}

%check
./all-tests.sh

%files
%license LICENSE
%{_bindir}/%{name}

%changelog
* Mon Jan 27 2025 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch for deterministic output order
* Mon Sep 30 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to verson 1.4.0
  * Added joker.url/parse-query function.
  * Added joker.io/read function.
  * Fixes Close file in load-file
- Added unit test run in the build
* Sat Mar 30 2024 Jochen Breuer <brejoc@gmail.com> - 1.3.5
- Update to version 1.3.5
  * joker.json/write-string serializes empty collections as null: gh#498
  * Updated vendor archive
* Sun Mar  3 2024 Jochen Breuer <brejoc@gmail.com> - 1.3.4
- Update to version 1.3.4
  * Added joker.time/day-of-year function.
  * Updated vendor archive
* Thu Dec 21 2023 Jochen Breuer <brejoc@gmail.com> - 1.3.3
- Update to version 1.3.3
  * Updated vendor archive
  * Create a_data.go in a reproducible way (thanks @bmwiedemann !)
  * add abs to cljs (thanks @harold !)
  * Bump golang.org/x/crypto from 0.14.0 to 0.17.0
* Fri Nov  3 2023 Jochen Breuer <brejoc@gmail.com> - 1.3.1
- Update to version 1.3.1
  * Updated vendor archive
  * Linter improvements: add parse-uuid to cljs (gh#489)
* Wed Oct  4 2023 Jochen Breuer <brejoc@gmail.com> - 1.3.0
- Initial commit of Joker version 1.3.0 including vendor archive
